package com.example.as_trak;

import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListPopupWindow;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.databinding.DataBindingUtil;
import androidx.databinding.ObservableBoolean;
import androidx.databinding.ObservableInt;

import com.example.as_trak.adapter.CargoInfoAdapter;
import com.example.as_trak.adapter.FlightInfoAdapter;
import com.example.as_trak.base.BaseActivity;
import com.example.as_trak.databinding.ActivityLoadMainBinding;
import com.example.as_trak.dialog.AddFlightDialog;
import com.example.as_trak.entity.CargoInfo;
import com.example.as_trak.entity.ContainerType;
import com.example.as_trak.entity.FlightInfo;
import com.example.as_trak.entity.LoadOperation;

import org.litepal.LitePal;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

public class LoadMainActivity extends BaseActivity implements AddFlightDialog.AddFlightDialogCall, CargoInfoAdapter.CargoInfoCall, AdapterView.OnItemClickListener {
    private ObservableBoolean visibState;
    private AddFlightDialog addFlightDialog;
    private List<FlightInfo> flightList;
    private ListPopupWindow lpw;
    private FlightInfo flightInfoTag;
    private CargoInfoAdapter cargoInfoAdapter;
    private List<CargoInfo> cargoInfoList;
    private FlightInfoAdapter adapter;
    private ActivityLoadMainBinding binding;
    private ObservableInt cargoQty;
    private ObservableInt loadQty;
    private androidx.appcompat.app.AlertDialog.Builder alertDialog;
    private String[] loadStateList;
    private AlertDialog.Builder builder;    // 长按删除
    private AlertDialog.Builder selectCargoType;//
    private Intent intent; // 跳转扫描界面

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = DataBindingUtil.setContentView(this, R.layout.activity_load_main);
        visibState = new ObservableBoolean();
        visibState.set(true);
        binding.setVisibState(visibState);
        // 装载器适配
        cargoInfoAdapter = new CargoInfoAdapter(this, this);
        binding.setAdapter(cargoInfoAdapter);
        initAddFlight(); // 航班添加框
        intent = new Intent(this, LoadScanActivity.class);
        cargoQty = new ObservableInt();
        loadQty = new ObservableInt();
        binding.setQty1(cargoQty);
        binding.setQty2(loadQty);
        initAlertDialog();

    }

    private void initAlertDialog() {
        builder = new AlertDialog.Builder(this);
        builder.setTitle("删除确认").setMessage("是否确定删除装载单元").setNegativeButton("取消", null);
        loadStateList = getResources().getStringArray(R.array.loadState);
        alertDialog = new androidx.appcompat.app.AlertDialog.Builder(this);
        alertDialog.setTitle("选择装载量").setNegativeButton("取消", null).create();
    }

    // 初始化航班添加
    private void initAddFlight() {
        addFlightDialog = new AddFlightDialog(this);
        addFlightDialog.setCall(this);
        // 航班选择框
        lpw = new ListPopupWindow(this);
        lpw.setAnchorView(binding.loadMainFlightCode);
        // 航班查询
        flightList = LitePal.order("createTime desc").find(FlightInfo.class);
        if (flightList == null) flightList = new ArrayList<>();
        adapter = new FlightInfoAdapter(this, flightList);
        lpw.setAdapter(adapter);
        lpw.setOnItemClickListener(this);
        binding.loadMainFlightCode.setOnClickListener(v -> {
            lpw.show();
        });
    }

    @Override
    protected void onResume() {
        super.onResume();
        initInputCargo();
        initScan();
    }

    @Override
    protected void onStop() {
        super.onStop();
        unregisterReceiver(myReceiver);
    }

    // 初始化添加货箱
    private void initInputCargo() {
        List<ContainerType> list = LitePal.findAll(ContainerType.class);
        Log.e("TAG", "onCreate:" + list.toString());
        if (list != null) {
            int size = list.size();
            List<String> list1 = new ArrayList<>(size);
            List<String> list2 = new ArrayList<>(size);
            List<String> list3 = new ArrayList<>(size);
            list.forEach(t -> {
                if (t.getType().equals("1")) {
                    list1.add(t.getTypeName());
                }else if (t.getType().equals("2")) {
                    list2.add(t.getTypeName());
                } else {
                    list3.add(t.getTypeName());
                }
            });
            if (list1.isEmpty() || list2.isEmpty()|| list3.isEmpty()) {
                Toast.makeText(this, "基础信息未维护", Toast.LENGTH_SHORT).show();
                Intent intent1 = new Intent(this, SettingActivity.class);
                startActivity(intent1);
            }
            binding.setList1(list1);
            binding.setList2(list2);
            binding.setList3(list3);

        }
    }

    // 显示航班添加框
    public void loadAddFlight(View view) {
        addFlightDialog.show();
    }

    // 显示添加货箱按钮
    public void loadAddEdit(View view) {
        visibState.set(false);
    }


    // 手动添加货箱
    public void loadAddCargo(View view) {
        if (flightInfoTag == null) return;
        String cargoCode = binding.loadMainCargoCode.getText().toString();
        // if (cargoCode.length() != 5) {
        //     Toast.makeText(this, "填写格式不规范", Toast.LENGTH_SHORT).show();
        //     return;
        // }
        String cargoCode0 = binding.loadMainCargoCode0.getSelectedItem().toString();
        String cargoCode3=binding.loadMainCargoCode3.getSelectedItem().toString();
        cargoCode = cargoCode0 + cargoCode+cargoCode3;
        addCargo(cargoCode, binding.loadMainCargoCode2.getSelectedItem().toString());
    }

    // 扫描添加货箱
    @SuppressLint("NotifyDataSetChanged")
    public void loadAddCargo1(View view) {
        if (flightInfoTag == null) return;
        String code0 = binding.loadMainCargoSanCode.getText().toString();

        if (code0.isEmpty()) return;
        addCargo(code0, binding.loadMainSanTypeSpinner.getSelectedItem().toString());
    }

    @SuppressLint("NotifyDataSetChanged")
    private void addCargo(String cargoCode, String type) {
        int id = flightInfoTag.getId();
        int countTag = LitePal.where("cargoCode= ? and flightId=?", cargoCode, String.valueOf(id)).count(CargoInfo.class);
        if (countTag > 0) {
            Toast.makeText(this, "装载单元已经绑定", Toast.LENGTH_SHORT).show();
            return;
        }
        CargoInfo cargoInfo = new CargoInfo();
        cargoInfo.setCount(0);
        cargoInfo.setCargoCode(cargoCode);
        cargoInfo.setFlightId(id);
        cargoInfo.setState("未装载");
        cargoInfo.setCargoType(type);
        cargoInfo.save();
        cargoInfoList.add(cargoInfo);
        int size = cargoInfoList.size();
        cargoQty.set(size);
        cargoInfoAdapter.notifyItemInserted(size - 1);
        binding.loadMainCargoCode.setText(null);
        binding.loadMainCargoSanCode.setText(null);
        Toast.makeText(this, "绑定成功", Toast.LENGTH_SHORT).show();
    }

    public void saveNumber(View view) {
        flightInfoTag.setJieguiQty(binding.loadMainJieguiQty.getText().toString());
        flightInfoTag.update(flightInfoTag.getId());
        Toast.makeText(this, "保存成功", Toast.LENGTH_SHORT).show();
    }

    // 关闭货箱添加
    public void loadCloseEdit(View view) {
        visibState.set(true);
        binding.loadMainCargoCode.setText(null);
    }

    /**
     * 返回新增的航班信息
     *
     * @param flightCode  航班编号
     * @param destination 三字代码
     * @param date        日期
     * @param time        时间
     */
    @Override
    public void flightInfo(String flightCode, String destination, String date, String time) {
        FlightInfo flightInfo = new FlightInfo();
        flightInfo.setFlightCode(flightCode);
        flightInfo.setDestination(destination);
        flightInfo.setTakeoffDate(date);
        flightInfo.setTakeoffTime(time);
        flightInfo.setCreateTime(new Date());
        flightInfo.save();
        addFlightDialog.dismiss();
        flightList.add(flightInfo);
        adapter.notifyDataSetChanged();
    }

    // 删除装载单元
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void longClickCargoInfo(int index) {
        CargoInfo cargoInfo = cargoInfoList.get(index);
        if (!cargoInfo.getState().equals("未装载")) {
            Toast.makeText(this, "已经装载行李，不能删除", Toast.LENGTH_SHORT).show();
            return;
        }

        builder.setPositiveButton("确定", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                cargoInfo.delete();
                cargoInfoList.remove(index);
                cargoInfoAdapter.notifyDataSetChanged();
                Toast.makeText(LoadMainActivity.this, "删除完成", Toast.LENGTH_SHORT).show();
            }
        }).show();

    }

    // 修改装载量
    @Override
    public void updateState(int index) {
        CargoInfo cargoInfo = cargoInfoList.get(index);
        alertDialog.setItems(loadStateList, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                cargoInfo.setLoadState(loadStateList[which]);
                cargoInfo.update(cargoInfo.getId());
                cargoInfoAdapter.notifyItemChanged(index);
            }
        }).show();
    }

    // 选中航班
    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        flightInfoTag = flightList.get(position);
        binding.loadMainJieguiQty.setText(flightInfoTag.getJieguiQty());
        // 添加输入框
        binding.loadMainFlightCode.setText(flightInfoTag.getFlightCode());
        // 查询货框
        selectCargo();
        Toast.makeText(this, "查询成功", Toast.LENGTH_SHORT).show();
        lpw.dismiss();
    }

    // 返回时调
    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        Log.e("TAG", "onActivityResult:重加载");
        selectCargo();
    }

    // 查询装载单元 内 数量
    @SuppressLint("NotifyDataSetChanged")
    private void selectCargo() {
        cargoInfoList = LitePal.where("flightId = ? ", String.valueOf(flightInfoTag.getId())).find(CargoInfo.class);
        AtomicInteger tag = new AtomicInteger();
        if (!cargoInfoList.isEmpty()) {
            cargoInfoList.forEach(cargoInfo -> {
                int countNum = LitePal.where("cargoId = ? and type ='装载' and (state IS NULL or state = '修改')", String.valueOf(cargoInfo.getId())).count(LoadOperation.class);
                cargoInfo.setCount(countNum);
                tag.addAndGet(countNum);
            });
        }
        cargoQty.set(cargoInfoList.size());
        loadQty.set(tag.intValue());
        cargoInfoAdapter.setList(cargoInfoList);
        cargoInfoAdapter.notifyDataSetChanged();
    }

    // 跳转装载页面
    public void clickCargoInfo(View view) {
        if (flightInfoTag == null) {
            Toast.makeText(this, "没有选择航班", Toast.LENGTH_SHORT).show();
            return;
        }
        if (cargoInfoList == null || cargoInfoList.isEmpty()) {
            Toast.makeText(this, "没有添加装载单元", Toast.LENGTH_SHORT).show();
            return;
        }

        ContainerType containerType = LitePal.where("typeName = ? and type =3 ",
                flightInfoTag.getFlightCode().substring(0, 2)).findFirst(ContainerType.class);
        boolean b = containerType != null;
        intent.putExtra("checkState",b);
        if (b){
            intent.putExtra("checkCode",containerType.getCheckCode());
        }

        intent.putExtra("id", flightInfoTag.getId());
        startActivityForResult(intent, 0);
    }

    // 扫描装载单元
    @Override
    public void sanCodeResult(String code) {
        super.sanCodeResult(code);
        if (code.length() < 8) {
            Toast.makeText(this, "扫描数据:" + code + " 异常", Toast.LENGTH_SHORT).show();
            return;
        }
        binding.loadMainCargoSanCode.setText(code);

    }



}