package com.example.as_trak;

import android.annotation.SuppressLint;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import androidx.appcompat.app.AlertDialog;
import androidx.databinding.DataBindingUtil;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.example.as_trak.adapter.CargoListAdapter;
import com.example.as_trak.adapter.LoadInfoAdapter;
import com.example.as_trak.base.BaseActivity;
import com.example.as_trak.databinding.ActivityLoadScanBinding;
import com.example.as_trak.dialog.TipDialog;
import com.example.as_trak.dialog.UpdataDialog;
import com.example.as_trak.entity.CargoInfo;
import com.example.as_trak.entity.FlightInfo;
import com.example.as_trak.entity.LoadOperation;

import org.litepal.LitePal;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class LoadScanActivity extends BaseActivity implements CargoListAdapter.CargoInfoCall, LoadInfoAdapter.LoadInfoCall, View.OnLongClickListener {
    private final Handler handler = new Handler(Looper.getMainLooper());
    private List<CargoInfo> cargoInfoList;
    private CargoListAdapter adapter;
    private List<LoadOperation> loadOperations;
    private CargoInfo cargoInfoTag;
    private FlightInfo flightInfo;
    private LoadInfoAdapter loadInfoAdapter;
    private DateTimeFormatter formatter; // 定义时间格式
    private UpdataDialog updataDialog;
    private ActivityLoadScanBinding binding;  // 装载完成对话框
    private TipDialog tipDialog;
    private AlertDialog.Builder alertDialog;
    private String checkCode;
    private boolean checkState;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = DataBindingUtil.setContentView(this, R.layout.activity_load_scan);
        initScan();
        Intent intent = getIntent();
        int id = intent.getIntExtra("id", 0);
        checkCode = intent.getStringExtra("checkCode");
        checkState = intent.getBooleanExtra("checkState", false);
        // 航班显示
        flightInfo = LitePal.where("id= ?", String.valueOf(id)).findFirst(FlightInfo.class);
        binding.setData(flightInfo);
        // 货箱显示
        cargoInfoList = LitePal.where("flightId = ?", String.valueOf(id)).find(CargoInfo.class);
        adapter = new CargoListAdapter(this, this);
        adapter.setList(cargoInfoList);
        binding.setAdapter1(adapter);
        formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        loadInfoAdapter = new LoadInfoAdapter(this, this);
        loadInfoAdapter.setRecyclerView(binding.loadInfoRecyclerview);
        binding.setAdapter2(loadInfoAdapter);
        binding.loadScanSubmit.setOnLongClickListener(this);
        initDialog();
    }

    // 初始化弹窗
    @SuppressLint("NotifyDataSetChanged")
    private void initDialog() {
        updataDialog = new UpdataDialog(this);
        updataDialog.setUpdataDialogCall((tag, code, index) -> {
            if (tag.equals("行李")) {
                LoadOperation loadOperation = loadOperations.get(index);
                loadOperation.setOldLuggageCode(loadOperation.getLuggageCode());
                loadOperation.setLuggageCode(code);
                loadOperation.setState("修改");
                loadOperation.update(loadOperation.getId());
            } else if (tag.equals("装载单元")) {
                // 128
                CargoInfo cargoInfo = cargoInfoList.get(index);
                int id = cargoInfo.getId();
                LoadOperation updateBeen = new LoadOperation();
                updateBeen.setUpdateCargoTag(1);
                String formattedTime = LocalDateTime.now().format(formatter);
                updateBeen.setLoadTime(formattedTime);
                updateBeen.setCargoCode(code);
                updateBeen.updateAll("cargoId =?", String.valueOf(id));//修改行李
                cargoInfo.setCargoCode(code);
                cargoInfo.update(id);//修改货箱
                if (cargoInfoTag!=null){
                    cargoInfoTag.setCargoCode(code);//修改点击
                }

                adapter.notifyDataSetChanged();
            }
            loadInfoAdapter.notifyDataSetChanged();
            updataDialog.dismiss();
        });
        tipDialog = new TipDialog(this);
        tipDialog.setTipCall(this::loadLastFun);
        alertDialog = new AlertDialog.Builder(this);
        alertDialog.setTitle("装载完成提示").setMessage("确认装载完成").setNegativeButton("取消", null).setPositiveButton("确认", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                if (cargoInfoTag == null) {
                    Toast.makeText(LoadScanActivity.this, "没有选择装载单元", Toast.LENGTH_SHORT).show();
                    return;
                }
                cargoInfoTag.setState("装载完成");
                cargoInfoTag.update(cargoInfoTag.getId());
                adapter.notifyDataSetChanged();
                Toast.makeText(LoadScanActivity.this, "装载完成", Toast.LENGTH_SHORT).show();
            }
        }).create();
    }

    // 点击装载单元
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void clickCargoInfo(int index) {
        cargoInfoTag = cargoInfoList.get(index);
        loadOperations = LitePal.where("cargoId =? and type = ? and (state IS NULL or state = '修改') ", String.valueOf(cargoInfoTag.getId()), "装载").order("id desc").find(LoadOperation.class);
        Log.e("TAG", "clickCargoInfo:" + loadOperations);
        loadInfoAdapter.setList(loadOperations);
        loadInfoAdapter.notifyDataSetChanged();
    }

    // 长按货箱
    @Override
    public void longClickCargoInfo(int index) {
        // 93
        CargoInfo cargoInfo = cargoInfoList.get(index);
        updataDialog.setIndex(index);
        updataDialog.setCode(cargoInfo.getCargoCode());
        updataDialog.setTag("装载单元");
        updataDialog.show();
    }

    // 扫码结果
    @Override
    public void sanCodeResult(String code) {
        super.sanCodeResult(code);
        binding.loadSanInfoCode.setText(code);
        // 先验证扫描情况
        String regex = "^[A-Za-z]{3}\\d{5}\\w{2}";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher = pattern.matcher(code);

        if (matcher.find()) {
            String group = matcher.group();
            // Log.e("TAG", "sanCodeResult:" + matcher.group());
            for (int i = 0; i < cargoInfoList.size(); i++) {
                if (cargoInfoList.get(i).getCargoCode().equals(group)) {
                    RecyclerView.LayoutManager layoutManager = binding.scanR1.getLayoutManager();
                    if (layoutManager instanceof LinearLayoutManager) {
                        View itemView = layoutManager.findViewByPosition(i);
                        if (itemView != null) {
                            itemView.performClick(); //
                            Log.e("TAG", "触发点击事件:" + i);
                        }
                    }
                    return;
                }
            }
        }

        addInfo(code);
    }

    // 手动添加扫描结果
    public void addSanResult(View view) {
        String code = binding.loadSanInfoCode.getText().toString();
        addInfo(code);
    }

    // 添加行李
    private void addInfo(String code) {
        if (cargoInfoTag == null) {
            Toast.makeText(this, "没有选择装载单元", Toast.LENGTH_SHORT).show();
            return;
        }
        if (checkState) {
            String pattern = "^" + checkCode + "\\d+";

            boolean isMatch = Pattern.matches(pattern, code);
            if (!isMatch) {
                tipDialog.showError("校验失败：" + code + "，不允许装机", code, true);
                return;
            }
        }
        loadLastFun(code);
        // if (cargoInfoTag.getState().equals("装载完成")) {
        //     Toast.makeText(this, "装载单元已经装载完成", Toast.LENGTH_SHORT).show();
        //     return;
        // }

    }

    // 插入数据库
    private void loadLastFun(String code) {
        int count = LitePal.where("flightId= ? and luggageCode=?  and type ='装载' and (state IS NULL or state = '修改')  ", String.valueOf(flightInfo.getId()), code).count(LoadOperation.class);
        if (count > 0) {
            tipDialog.showError("行李条码：" + code + "重复", code, false);
            return;
        }
        tipDialog.showSuccess(code + "\n装载成功");
        // 添加行李
        LoadOperation loadOperation = new LoadOperation();
        loadOperation.setFlightCode(flightInfo.getFlightCode());
        loadOperation.setFlightId(flightInfo.getId());
        loadOperation.setDestination(flightInfo.getDestination());
        loadOperation.setTakeoffTime(flightInfo.getTakeoffTime());
        loadOperation.setCargoCode(cargoInfoTag.getCargoCode());
        loadOperation.setCargoId(cargoInfoTag.getId());
        loadOperation.setLuggageCode(code);
        // loadOperation.setUser();
        String formattedTime = LocalDateTime.now().format(formatter); // 格式化当前时间
        loadOperation.setLoadTime(formattedTime);
        loadOperation.setType("装载");
        loadOperation.save();
        loadOperations.add(0, loadOperation);// 列表
        loadInfoAdapter.notifyItemInserted(0);
        binding.loadInfoRecyclerview.scrollToPosition(0);
        loadOperation.setBg(true);
        changeBackgroundColorAfterDelay(loadOperation);
        // 更新货箱状态
        int size = loadOperations.size();
        Log.e("TAG", "更新的id:" + cargoInfoTag.getId() + "数量:" + size);
        cargoInfoTag.setCount(size);
        cargoInfoTag.setState("装载中");
        cargoInfoTag.update(cargoInfoTag.getId());
    }

    private void changeBackgroundColorAfterDelay(LoadOperation loadOperation) {
        handler.postDelayed(() -> {
            loadOperation.setBg(false);
            loadInfoAdapter.notifyDataSetChanged();
        }, 3000);
    }

    // 修改行李号
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void updateCargoInfo(int index) {
        // if (cargoInfoTag.getState().equals("装载完成")) {
        //     Toast.makeText(this, "装载单元已经装载完成", Toast.LENGTH_SHORT).show();
        //     return;
        // }
        LoadOperation loadOperation = loadOperations.get(index);
        updataDialog.setIndex(index);
        updataDialog.setTag("行李");
        updataDialog.setCode(loadOperation.getLuggageCode());
        updataDialog.show();
    }

    // 删除行李
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void deleteCargoInfo(int index) {
        // if (cargoInfoTag.getState().equals("装载完成")) {
        //     Toast.makeText(this, "装载单元已经装载完成", Toast.LENGTH_SHORT).show();
        //     return;
        // }
        LoadOperation loadOperation = loadOperations.get(index);
        loadOperation.setState("删除");
        loadOperation.update(loadOperation.getId());
        loadOperations.remove(index);
        cargoInfoTag.setCount(loadOperations.size());
        cargoInfoTag.update(cargoInfoTag.getId());
        loadInfoAdapter.notifyDataSetChanged();
    }


    // 装载完毕
    @Override
    @SuppressLint("NotifyDataSetChanged")
    public boolean onLongClick(View v) {
        alertDialog.show();
        return true;
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (myReceiver != null) unregisterReceiver(myReceiver);
    }

}