package com.example.as_trak.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.databinding.DataBindingUtil;
import androidx.recyclerview.widget.RecyclerView;

import com.example.as_trak.R;
import com.example.as_trak.databinding.ItemCargoBinding;
import com.example.as_trak.databinding.ItemCargoListBinding;
import com.example.as_trak.entity.CargoInfo;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;

public class CargoListAdapter extends RecyclerView.Adapter<CargoListAdapter.MyViewHolder> {
    private Context context;
    private LayoutInflater inflater;
    private List<CargoInfo> list;
    private CargoInfoCall call;
    private List<Boolean> bgList;
    private int tag = -1;

    public CargoListAdapter(Context context, CargoInfoCall call) {
        this.context = context;
        inflater = LayoutInflater.from(context);
        this.call = call;
    }

    public void setList(List<CargoInfo> list) {
        this.list = list;
        initBgLsit(list.size());
    }

    private void initBgLsit(int size) {
        bgList = new ArrayList<>(size);
        for (int i = 0; i < size; i++) {
            bgList.add(false);
        }
    }

    @NonNull
    @Override
    public MyViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        ItemCargoListBinding binding = DataBindingUtil.inflate(inflater, R.layout.item_cargo_list, parent, false, null);
        return new MyViewHolder(binding);
    }

    @Override
    public void onBindViewHolder(@NonNull MyViewHolder holder, @SuppressLint("RecyclerView") int position) {
        ItemCargoListBinding binding = holder.binding;
        TextView itemCargoCode = binding.itemCargoCode;

        CargoInfo cargoInfo = list.get(position);
        itemCargoCode.setText(cargoInfo.getCargoCode());
        if (bgList.get(position)) {
            itemCargoCode.setBackgroundResource(R.drawable.item_click_bg);
        } else {
            if (cargoInfo.getState().equals("装载完成")) {
                itemCargoCode.setBackgroundResource(R.drawable.item_over);
            }else {
                itemCargoCode.setBackgroundResource(R.drawable.select_bg);
            }
        }
        binding.itemCargoLinear.setOnClickListener(v -> {
            if (tag != -1) {
                bgList.set(tag, false);
                notifyItemChanged(tag);
                Log.e("TAG", "上次点击:" + tag);
            }
            bgList.set(position, true);
            call.clickCargoInfo(position);
            tag = position;
            notifyItemChanged(position);

            Log.e("TAG", "本次点击:" + position);
        });

        binding.itemCargoLinear.setOnLongClickListener(v -> {
            call.longClickCargoInfo(position);
            return true;
        });
    }

    @Override
    public int getItemCount() {
        return list == null ? 0 : list.size();
    }


    static class MyViewHolder extends RecyclerView.ViewHolder {
        private ItemCargoListBinding binding;

        public MyViewHolder(ItemCargoListBinding binding) {
            super(binding.getRoot());
            this.binding = binding;
        }


    }

    public interface CargoInfoCall {
        void clickCargoInfo(int index);
        void longClickCargoInfo(int index);
    }
}
