package com.example.as_trak.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.PopupMenu;
import android.widget.PopupWindow;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.databinding.DataBindingUtil;
import androidx.recyclerview.widget.RecyclerView;

import com.example.as_trak.R;
import com.example.as_trak.databinding.ItemLoadInfoBinding;
import com.example.as_trak.entity.LoadOperation;

import java.util.List;

public class LoadInfoAdapter extends RecyclerView.Adapter<LoadInfoAdapter.MyViewHolder> {
    private Context context;
    private LayoutInflater inflater;
    private List<LoadOperation> list;
    private LoadInfoCall call;

    public LoadInfoAdapter(Context context, LoadInfoCall call) {
        this.context = context;
        inflater = LayoutInflater.from(context);
        this.call = call;
    }

    public void setList(List<LoadOperation> list) {
        this.list = list;
    }

    @NonNull
    @Override
    public MyViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        ItemLoadInfoBinding binding = DataBindingUtil.inflate(inflater, R.layout.item_load_info, parent, false, null);
        return new MyViewHolder(binding);
    }

    @Override
    public void onBindViewHolder(@NonNull MyViewHolder holder, int position) {
        ItemLoadInfoBinding binding = holder.binding;
        LoadOperation data = list.get(position);
        if (data.getUpdateCargoTag()==0){
            data.setOrderNum(list.size()-position);
        }else {
            data.setOrderNum(0);
        }

        binding.setData(data);
        // binding.itemLoadD.setOnClickListener(v -> call.deleteCargoInfo(position));
        binding.itemLoadU.setOnLongClickListener(v -> {
            // call.updateCargoInfo(position);

            showPopupMenu(v, position);
            // showPopupWindow(v);
            return true;
        });
    }

    @Override
    public int getItemCount() {
        return list == null ? 0 : list.size();
    }


    static class MyViewHolder extends RecyclerView.ViewHolder {
        private ItemLoadInfoBinding binding;

        public MyViewHolder(ItemLoadInfoBinding binding) {
            super(binding.getRoot());
            this.binding = binding;
        }


    }

    public interface LoadInfoCall {
        void updateCargoInfo(int index);
        void deleteCargoInfo(int index);
    }


    private void showPopupMenu(View view, int index) {
        PopupMenu popupMenu = new PopupMenu(view.getContext(), view);
        popupMenu.getMenuInflater().inflate(R.menu.popup_menu, popupMenu.getMenu());
        popupMenu.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
            @SuppressLint("NonConstantResourceId")
            @Override
            public boolean onMenuItemClick(MenuItem menuItem) {
                int itemId = menuItem.getItemId();
                // 处理删除操作
                if (itemId == R.id.action_delete) {
                    call.deleteCargoInfo(index);
                    return true;
                } else if (itemId == R.id.action_edit) {
                    call.updateCargoInfo(index);
                    return true;
                }
                return false;
            }
        });
        popupMenu.show();
    }


    private Handler handler = new Handler(Looper.getMainLooper());
    private RecyclerView recyclerView;

    public void setRecyclerView(RecyclerView recyclerView) {
        this.recyclerView = recyclerView;
    }




}
