package com.example.as_trak.fragment;

import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.ContentResolver;
import android.content.ContentValues;
import android.content.Context;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;

import androidx.databinding.DataBindingUtil;
import androidx.fragment.app.Fragment;

import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.provider.MediaStore;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.AdapterView;
import android.widget.ListPopupWindow;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.example.as_trak.R;
import com.example.as_trak.adapter.FlightInfoAdapter;
import com.example.as_trak.adapter.LoadListAdapter;
import com.example.as_trak.databinding.FragmentFlightInfoBinding;
import com.example.as_trak.entity.CargoInfo;
import com.example.as_trak.entity.FlightInfo;
import com.example.as_trak.entity.LoadOperation;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.litepal.LitePal;

import java.io.IOException;
import java.io.OutputStream;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;


public class FlightInfoFragment extends Fragment implements AdapterView.OnItemClickListener {
    private LoadListAdapter adapter;
    private Context context;
    private ListPopupWindow lpw;
    private List<FlightInfo> flightList;
    private FragmentFlightInfoBinding binding;
    private String tagId;
    private ProgressDialog progressDialog;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        context = getContext();
        progressDialog = new ProgressDialog(context);
        progressDialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
        progressDialog.setCanceledOnTouchOutside(false);
        progressDialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
        progressDialog.setMessage("导出到excel...");

    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        binding = DataBindingUtil.inflate(inflater, R.layout.fragment_flight_info, container, false);
        adapter = new LoadListAdapter(getContext());
        binding.setAdapter(adapter);
        lpw = new ListPopupWindow(context);
        lpw.setAnchorView(binding.loadMainFlightCode);
        // 航班查询
        flightList = LitePal.order("createTime desc").find(FlightInfo.class);
        if (flightList == null) flightList = new ArrayList<>();
        lpw.setAdapter(new FlightInfoAdapter(context, flightList));
        lpw.setOnItemClickListener(this);
        binding.loadMainFlightCode.setOnClickListener(v -> {
            lpw.show();
        });
        binding.importLoadInfo.setOnClickListener(v -> {
            if (tagId == null) {
                return;
            }
            exportLoadOperationsByFlightId(context, tagId);
        });
        return binding.getRoot();
    }

    @SuppressLint({"NotifyDataSetChanged", "SetTextI18n"})
    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {

        FlightInfo flightInfo = flightList.get(position);
        binding.loadMainFlightCode.setText(flightInfo.getFlightCode());
        binding.loadMainFlightDate.setText(flightInfo.getTakeoffDate());
        binding.loadMainFlightNumber.setText("" + flightInfo.getJieguiQty());
        tagId = String.valueOf(flightInfo.getId());
        int countCargo = LitePal.where("flightId= ?", tagId).count(CargoInfo.class);
        binding.loadCountCargo.setText(String.valueOf(countCargo));
        int countOperation = LitePal.where("flightId= ? and type='装载' and (state IS NULL or state = '修改')  "
                , tagId).count(LoadOperation.class);
        binding.loadCountLuggage.setText(String.valueOf(countOperation));
        List<LoadOperation> list = LitePal.where("flightId= ?  and (state IS NULL or state = '修改')"
                , tagId).order("cargoId,id asc").find(LoadOperation.class);
        adapter.setList(list);
        adapter.notifyDataSetChanged();
        lpw.dismiss();

    }

    DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmmss");

    public void exportLoadOperationsByFlightId(Context context, String flightId) {
        progressDialog.show();
        new Thread(() -> {
            // 根据 flightId 查询 LoadOperation 数据
            List<LoadOperation> loadOperations = LitePal.where("flightId = ? and type='装载' and (state IS NULL or state = '修改')  ", flightId).find(LoadOperation.class);
            // 创建新的工作簿
            Workbook workbook = new XSSFWorkbook();
            Sheet sheet = workbook.createSheet("Load Operations");

            CellStyle headerCellStyle = workbook.createCellStyle();
            headerCellStyle.setAlignment(HorizontalAlignment.CENTER); // 设置水平居中
            headerCellStyle.setVerticalAlignment(VerticalAlignment.CENTER); // 设置垂直居中


            // 创建表头
            Row headerRow = sheet.createRow(0);
            String[] headers = {"序号", "航班号", "目的地代码", "起飞时间", "装载单元", "行李编码", "装载时间"};
            for (int i = 0; i < headers.length; i++) {
                Cell cell = headerRow.createCell(i);
                cell.setCellValue(headers[i]);
                sheet.setDefaultColumnStyle(i, headerCellStyle);
                if (i == 4 || i == 5 || i == 6) {
                    sheet.setColumnWidth(i, 5000);
                } else {
                    sheet.setColumnWidth(i, 3000);
                }

            }
            // 填充数据
            int rowNum = 1;
            int index = 0;
            for (LoadOperation loadOperation : loadOperations) {
                index = rowNum;
                Row row = sheet.createRow(rowNum++);
                row.createCell(0).setCellValue(index);
                row.createCell(1).setCellValue(loadOperation.getFlightCode());
                row.createCell(2).setCellValue(loadOperation.getDestination());
                row.createCell(3).setCellValue(loadOperation.getTakeoffTime());
                row.createCell(4).setCellValue(loadOperation.getCargoCode());
                row.createCell(5).setCellValue(loadOperation.getLuggageCode());
                row.createCell(6).setCellValue(loadOperation.getLoadTime());
            }

            // 使用 MediaStore 存储文件
            ContentResolver contentResolver = context.getContentResolver();
            ContentValues contentValues = new ContentValues();
            contentValues.put(MediaStore.MediaColumns.DISPLAY_NAME, "行李装载信息" + binding.loadMainFlightCode.getText().toString() +" "+
                    binding.loadMainFlightDate.getText().toString() + ".xlsx");
            contentValues.put(MediaStore.MediaColumns.MIME_TYPE, "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
                contentValues.put(MediaStore.MediaColumns.RELATIVE_PATH, Environment.DIRECTORY_DOCUMENTS);
            }

            Uri uri = contentResolver.insert(MediaStore.Files.getContentUri("external"), contentValues);
            if (uri != null) {
                try (OutputStream outputStream = contentResolver.openOutputStream(uri)) {
                    if (outputStream != null) {
                        workbook.write(outputStream);
                        Log.e("TAG", "exportLoadOperationsByFlightId:" + "数据已导出到 Excel 文件：" + uri.toString());
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                } finally {
                    try {
                        workbook.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
            new Handler(Looper.getMainLooper()).post(() -> {
                Toast.makeText(context, "导出成功", Toast.LENGTH_SHORT).show();
                if (progressDialog.isShowing()) {

                    progressDialog.dismiss();
                }
            });
        }).start();
    }
}